import * as FRAG from "@thatopen/fragments";
import * as OBC from "@thatopen/components";
import { GeometryCullerRenderer, StreamPropertiesSettings, StreamLoaderSettings } from "./src";
export * from "./src";
/**
 * The IfcStreamer component is responsible for managing and streaming tiled IFC data. It provides methods for loading, removing, and managing IFC models, as well as handling visibility and caching. 📕 [Tutorial](https://docs.thatopen.com/Tutorials/Components/Front/IfcStreamer). 📘 [API](https://docs.thatopen.com/api/@thatopen/components-front/classes/IfcStreamer).
 */
export declare class IfcStreamer extends OBC.Component implements OBC.Disposable {
    /**
     * A unique identifier for the component.
     * This UUID is used to register the component within the Components system.
     */
    static readonly uuid: "22437e8d-9dbc-4b99-a04f-d2da280d50c8";
    /** {@link OBC.Component.enabled} */
    enabled: boolean;
    /**
     * Event triggered when fragments are deleted.
     */
    readonly onFragmentsDeleted: OBC.Event<FRAG.Fragment[]>;
    /**
     * Event triggered when fragments are loaded.
     */
    readonly onFragmentsLoaded: OBC.Event<FRAG.Fragment[]>;
    /** {@link OBC.Disposable.onDisposed} */
    readonly onDisposed: OBC.Event<unknown>;
    /**
     * The data of the streamed models. It defines the geometries, their instances, its bounding box (OBB) and the assets to which they belong.
     */
    models: {
        [modelID: string]: {
            assetsMap: Map<number, OBC.StreamedAsset>;
            geometries: OBC.StreamedGeometries;
            /** @deprecated use assetsMap instead */
            assets: OBC.StreamedAsset[];
        };
    };
    /**
     * Importer of binary IFC data previously converted to fragment tiles.
     */
    serializer: FRAG.StreamSerializer;
    /**
     * Maximum time in milliseconds for a geometry to stay in the RAM cache.
     */
    maxRamTime: number;
    /**
     * Flag indicating whether to use the local cache for storing geometry files.
     */
    useCache: boolean;
    /**
     * Flag to cancel the files that are being currently loaded.
     */
    cancel: boolean;
    /**
     * The URL of the data source for the streaming service.
     * It should be set before using the streaming service. Alternatively, you can use a custom fetch function.
     */
    url: string;
    /**
     * Function used to retrieve tiles. Can be overriden to work with specific backends.
     */
    fetch: (fileName: string) => Promise<Response | File>;
    /**
     * Cache system that uses the File System API.
     */
    fileDB: FRAG.StreamerFileDb;
    private _culler;
    private _world;
    private _ramCache;
    private _isDisposing;
    private _geometryInstances;
    private _loadedFragments;
    private fragIDData;
    private _baseMaterial;
    private _baseMaterialT;
    /**
     * The world in which the fragments will be displayed.
     * It must be set before using the streaming service.
     * If not set, an error will be thrown when trying to access the world.
     */
    get world(): OBC.World;
    /**
     * Sets the world in which the fragments will be displayed.
     * @param world - The new world to be set.
     */
    set world(world: OBC.World);
    /**
     * The culler used for managing and rendering the fragments.
     * It is automatically created when the world is set.
     */
    get culler(): GeometryCullerRenderer;
    constructor(components: OBC.Components);
    /** {@link OBC.Disposable.dispose} */
    dispose(): void;
    /**
     * Loads a new fragment group into the scene using streaming.
     *
     * @param settings - The settings for the new fragment group.
     * @param coordinate - Whether to federate this model with the rest.
     * @param properties - Optional properties for the new fragment group.
     * @returns The newly loaded fragment group.
     */
    load(settings: StreamLoaderSettings, coordinate: boolean, properties?: StreamPropertiesSettings): Promise<FRAG.FragmentsGroup>;
    /**
     * Removes a fragment group from the scene.
     *
     * @param modelID - The unique identifier of the fragment group to remove.
     *
     * @deprecated use OBC.FragmentsManager.disposeGroup instead.
     */
    remove(modelID: string): void;
    /**
     * Sets the visibility of items in fragments based on the provided filter.
     *
     * @param visible - The visibility state to set.
     * @param filter - A map of fragment IDs to arrays of item IDs.
     *                  Only items with IDs present in the arrays will be visible.
     *                  If not provided, it will take all loaded models as filter.
     */
    setVisibility(visible: boolean, filter?: FRAG.FragmentIdMap): void;
    /**
     * Clears the local cache used for storing downloaded fragment files.
     *
     * @returns A Promise that resolves when the cache is cleared.
     */
    clearCache(): Promise<void>;
    /**
     * Sets or unsets the specified fragments as static. Static fragments are streamed once and then kept in memory.
     *
     * @param ids - The list of fragment IDs to make static.
     * @param active - Whether these items should be static or not.
     * @param culled - Whether these items should be culled or not. If undefined: active=true will set items as culled, while active=false will remove items from both the culled and unculled list.
     */
    setStatic(ids: Iterable<string>, active: boolean, culled?: boolean): Promise<void>;
    /**
     * Gets a FragmentsGroup with the OBB of the specified items. Keep in mind that you will need to dispose this group yourself using the dispose(false) method (geometry is shared with bounding boxes used for visibility check).
     *
     * @param items - The items whose bounding boxes to get.
     */
    getBoundingBoxes(items: FRAG.FragmentIdMap): FRAG.FragmentsGroup;
    private loadFoundGeometries;
    private unloadLostGeometries;
    private setMeshVisibility;
    private newFragment;
    private disposeStreamedGroup;
    private cancelLoading;
    private loadFragmentFile;
}
